# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['MitigationArgs', 'Mitigation']

@pulumi.input_type
class MitigationArgs:
    def __init__(__self__, *,
                 ip: pulumi.Input[builtins.str],
                 ip_on_mitigation: pulumi.Input[builtins.str],
                 permanent: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Mitigation resource.
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_mitigation: IPv4 address
               * `permanent ` - Set on true if the IP is on permanent mitigation
        :param pulumi.Input[builtins.bool] permanent: Set on true if your ip is on permanent mitigation
        """
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "ip_on_mitigation", ip_on_mitigation)
        if permanent is not None:
            pulumi.set(__self__, "permanent", permanent)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[builtins.str]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="ipOnMitigation")
    def ip_on_mitigation(self) -> pulumi.Input[builtins.str]:
        """
        IPv4 address
        * `permanent ` - Set on true if the IP is on permanent mitigation
        """
        return pulumi.get(self, "ip_on_mitigation")

    @ip_on_mitigation.setter
    def ip_on_mitigation(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip_on_mitigation", value)

    @property
    @pulumi.getter
    def permanent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set on true if your ip is on permanent mitigation
        """
        return pulumi.get(self, "permanent")

    @permanent.setter
    def permanent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "permanent", value)


@pulumi.input_type
class _MitigationState:
    def __init__(__self__, *,
                 auto: Optional[pulumi.Input[builtins.bool]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_mitigation: Optional[pulumi.Input[builtins.str]] = None,
                 permanent: Optional[pulumi.Input[builtins.bool]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Mitigation resources.
        :param pulumi.Input[builtins.bool] auto: Set on true if the IP is on auto-mitigation
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_mitigation: IPv4 address
               * `permanent ` - Set on true if the IP is on permanent mitigation
        :param pulumi.Input[builtins.bool] permanent: Set on true if your ip is on permanent mitigation
        :param pulumi.Input[builtins.str] state: Current state of the IP on mitigation
        """
        if auto is not None:
            pulumi.set(__self__, "auto", auto)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if ip_on_mitigation is not None:
            pulumi.set(__self__, "ip_on_mitigation", ip_on_mitigation)
        if permanent is not None:
            pulumi.set(__self__, "permanent", permanent)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def auto(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set on true if the IP is on auto-mitigation
        """
        return pulumi.get(self, "auto")

    @auto.setter
    def auto(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="ipOnMitigation")
    def ip_on_mitigation(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4 address
        * `permanent ` - Set on true if the IP is on permanent mitigation
        """
        return pulumi.get(self, "ip_on_mitigation")

    @ip_on_mitigation.setter
    def ip_on_mitigation(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_on_mitigation", value)

    @property
    @pulumi.getter
    def permanent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set on true if your ip is on permanent mitigation
        """
        return pulumi.get(self, "permanent")

    @permanent.setter
    def permanent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "permanent", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current state of the IP on mitigation
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)


class Mitigation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_mitigation: Optional[pulumi.Input[builtins.str]] = None,
                 permanent: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Use this resource to manage an IP permanent mitigation.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        mitigation = ovh.ip.Mitigation("mitigation",
            ip="XXXXXX",
            ip_on_mitigation="XXXXXX")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_mitigation: IPv4 address
               * `permanent ` - Set on true if the IP is on permanent mitigation
        :param pulumi.Input[builtins.bool] permanent: Set on true if your ip is on permanent mitigation
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MitigationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to manage an IP permanent mitigation.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        mitigation = ovh.ip.Mitigation("mitigation",
            ip="XXXXXX",
            ip_on_mitigation="XXXXXX")
        ```

        :param str resource_name: The name of the resource.
        :param MitigationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MitigationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_mitigation: Optional[pulumi.Input[builtins.str]] = None,
                 permanent: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MitigationArgs.__new__(MitigationArgs)

            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            if ip_on_mitigation is None and not opts.urn:
                raise TypeError("Missing required property 'ip_on_mitigation'")
            __props__.__dict__["ip_on_mitigation"] = ip_on_mitigation
            __props__.__dict__["permanent"] = permanent
            __props__.__dict__["auto"] = None
            __props__.__dict__["state"] = None
        super(Mitigation, __self__).__init__(
            'ovh:Ip/mitigation:Mitigation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto: Optional[pulumi.Input[builtins.bool]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            ip_on_mitigation: Optional[pulumi.Input[builtins.str]] = None,
            permanent: Optional[pulumi.Input[builtins.bool]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None) -> 'Mitigation':
        """
        Get an existing Mitigation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto: Set on true if the IP is on auto-mitigation
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_mitigation: IPv4 address
               * `permanent ` - Set on true if the IP is on permanent mitigation
        :param pulumi.Input[builtins.bool] permanent: Set on true if your ip is on permanent mitigation
        :param pulumi.Input[builtins.str] state: Current state of the IP on mitigation
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MitigationState.__new__(_MitigationState)

        __props__.__dict__["auto"] = auto
        __props__.__dict__["ip"] = ip
        __props__.__dict__["ip_on_mitigation"] = ip_on_mitigation
        __props__.__dict__["permanent"] = permanent
        __props__.__dict__["state"] = state
        return Mitigation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def auto(self) -> pulumi.Output[builtins.bool]:
        """
        Set on true if the IP is on auto-mitigation
        """
        return pulumi.get(self, "auto")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="ipOnMitigation")
    def ip_on_mitigation(self) -> pulumi.Output[builtins.str]:
        """
        IPv4 address
        * `permanent ` - Set on true if the IP is on permanent mitigation
        """
        return pulumi.get(self, "ip_on_mitigation")

    @property
    @pulumi.getter
    def permanent(self) -> pulumi.Output[builtins.bool]:
        """
        Set on true if your ip is on permanent mitigation
        """
        return pulumi.get(self, "permanent")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        Current state of the IP on mitigation
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'OpensearchUserAcl',
    'PrometheusTarget',
    'GetCapabilitiesEngineResult',
    'GetCapabilitiesFlavorResult',
    'GetCapabilitiesOptionResult',
    'GetCapabilitiesPlanResult',
    'GetDatabaseEndpointResult',
    'GetDatabaseIpRestrictionResult',
    'GetDatabaseNodeResult',
]

@pulumi.output_type
class OpensearchUserAcl(dict):
    def __init__(__self__, *,
                 pattern: builtins.str,
                 permission: builtins.str):
        """
        :param builtins.str pattern: Pattern of the ACL.
        :param builtins.str permission: Permission of the ACL Available permission:
        """
        pulumi.set(__self__, "pattern", pattern)
        pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter
    def pattern(self) -> builtins.str:
        """
        Pattern of the ACL.
        """
        return pulumi.get(self, "pattern")

    @property
    @pulumi.getter
    def permission(self) -> builtins.str:
        """
        Permission of the ACL Available permission:
        """
        return pulumi.get(self, "permission")


@pulumi.output_type
class PrometheusTarget(dict):
    def __init__(__self__, *,
                 host: Optional[builtins.str] = None,
                 port: Optional[builtins.int] = None):
        """
        :param builtins.str host: Host of the endpoint
        :param builtins.int port: Connection port for the endpoint
        """
        if host is not None:
            pulumi.set(__self__, "host", host)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def host(self) -> Optional[builtins.str]:
        """
        Host of the endpoint
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        """
        Connection port for the endpoint
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetCapabilitiesEngineResult(dict):
    def __init__(__self__, *,
                 default_version: builtins.str,
                 description: builtins.str,
                 name: builtins.str,
                 ssl_modes: Sequence[builtins.str],
                 versions: Sequence[builtins.str]):
        """
        :param builtins.str default_version: Default version used for the engine.
        :param builtins.str description: Description of the plan.
        :param builtins.str name: Name of the plan.
        :param Sequence[builtins.str] ssl_modes: SSL modes for this engine.
        :param Sequence[builtins.str] versions: Versions available for this engine.
        """
        pulumi.set(__self__, "default_version", default_version)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "ssl_modes", ssl_modes)
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter(name="defaultVersion")
    def default_version(self) -> builtins.str:
        """
        Default version used for the engine.
        """
        return pulumi.get(self, "default_version")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the plan.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the plan.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="sslModes")
    def ssl_modes(self) -> Sequence[builtins.str]:
        """
        SSL modes for this engine.
        """
        return pulumi.get(self, "ssl_modes")

    @property
    @pulumi.getter
    def versions(self) -> Sequence[builtins.str]:
        """
        Versions available for this engine.
        """
        return pulumi.get(self, "versions")


@pulumi.output_type
class GetCapabilitiesFlavorResult(dict):
    def __init__(__self__, *,
                 core: builtins.int,
                 memory: builtins.int,
                 name: builtins.str,
                 storage: builtins.int):
        """
        :param builtins.int core: Flavor core number.
        :param builtins.int memory: Flavor ram size in GB.
        :param builtins.str name: Name of the plan.
        :param builtins.int storage: Flavor disk size in GB.
        """
        pulumi.set(__self__, "core", core)
        pulumi.set(__self__, "memory", memory)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "storage", storage)

    @property
    @pulumi.getter
    def core(self) -> builtins.int:
        """
        Flavor core number.
        """
        return pulumi.get(self, "core")

    @property
    @pulumi.getter
    def memory(self) -> builtins.int:
        """
        Flavor ram size in GB.
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the plan.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def storage(self) -> builtins.int:
        """
        Flavor disk size in GB.
        """
        return pulumi.get(self, "storage")


@pulumi.output_type
class GetCapabilitiesOptionResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str name: Name of the plan.
        :param builtins.str type: Type of the option.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the plan.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the option.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetCapabilitiesPlanResult(dict):
    def __init__(__self__, *,
                 backup_retention: builtins.str,
                 description: builtins.str,
                 name: builtins.str):
        """
        :param builtins.str backup_retention: Automatic backup retention duration.
        :param builtins.str description: Description of the plan.
        :param builtins.str name: Name of the plan.
        """
        pulumi.set(__self__, "backup_retention", backup_retention)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="backupRetention")
    def backup_retention(self) -> builtins.str:
        """
        Automatic backup retention duration.
        """
        return pulumi.get(self, "backup_retention")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the plan.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the plan.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetDatabaseEndpointResult(dict):
    def __init__(__self__, *,
                 component: builtins.str,
                 domain: builtins.str,
                 path: builtins.str,
                 port: builtins.int,
                 scheme: builtins.str,
                 ssl: builtins.bool,
                 ssl_mode: builtins.str,
                 uri: builtins.str):
        """
        :param builtins.str component: Type of component the URI relates to.
        :param builtins.str domain: Domain of the cluster.
        :param builtins.str path: Path of the endpoint.
        :param builtins.int port: Connection port for the endpoint.
        :param builtins.str scheme: Scheme used to generate the URI.
        :param builtins.bool ssl: Defines whether the endpoint uses SSL.
        :param builtins.str ssl_mode: SSL mode used to connect to the service if the SSL is enabled.
        :param builtins.str uri: URI of the endpoint.
        """
        pulumi.set(__self__, "component", component)
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "scheme", scheme)
        pulumi.set(__self__, "ssl", ssl)
        pulumi.set(__self__, "ssl_mode", ssl_mode)
        pulumi.set(__self__, "uri", uri)

    @property
    @pulumi.getter
    def component(self) -> builtins.str:
        """
        Type of component the URI relates to.
        """
        return pulumi.get(self, "component")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        """
        Domain of the cluster.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def path(self) -> builtins.str:
        """
        Path of the endpoint.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        Connection port for the endpoint.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def scheme(self) -> builtins.str:
        """
        Scheme used to generate the URI.
        """
        return pulumi.get(self, "scheme")

    @property
    @pulumi.getter
    def ssl(self) -> builtins.bool:
        """
        Defines whether the endpoint uses SSL.
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter(name="sslMode")
    def ssl_mode(self) -> builtins.str:
        """
        SSL mode used to connect to the service if the SSL is enabled.
        """
        return pulumi.get(self, "ssl_mode")

    @property
    @pulumi.getter
    def uri(self) -> builtins.str:
        """
        URI of the endpoint.
        """
        return pulumi.get(self, "uri")


@pulumi.output_type
class GetDatabaseIpRestrictionResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 ip: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str description: Description of the IP restriction
        :param builtins.str ip: Authorized IP
        :param builtins.str status: Current status of the cluster.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the IP restriction
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        Authorized IP
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current status of the cluster.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetDatabaseNodeResult(dict):
    def __init__(__self__, *,
                 network_id: builtins.str,
                 region: builtins.str,
                 subnet_id: builtins.str):
        """
        :param builtins.str network_id: Private network id in which the node should be deployed. It's the regional openstackId of the private network
        :param builtins.str region: Public cloud region in which the node should be deployed.
        :param builtins.str subnet_id: Private subnet ID in which the node is.
        """
        pulumi.set(__self__, "network_id", network_id)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "subnet_id", subnet_id)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> builtins.str:
        """
        Private network id in which the node should be deployed. It's the regional openstackId of the private network
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Public cloud region in which the node should be deployed.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> builtins.str:
        """
        Private subnet ID in which the node is.
        """
        return pulumi.get(self, "subnet_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpAddressArgs', 'IpAddress']

@pulumi.input_type
class IpAddressArgs:
    def __init__(__self__, *,
                 block: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a IpAddress resource.
        :param pulumi.Input[builtins.str] block: Your IP block.
        :param pulumi.Input[builtins.str] service_name: The internal name of your vrack
        """
        pulumi.set(__self__, "block", block)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def block(self) -> pulumi.Input[builtins.str]:
        """
        Your IP block.
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "block", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _IpAddressState:
    def __init__(__self__, *,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 gateway: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpAddress resources.
        :param pulumi.Input[builtins.str] block: Your IP block.
        :param pulumi.Input[builtins.str] gateway: Your gateway
        :param pulumi.Input[builtins.str] ip: Your IP block
        :param pulumi.Input[builtins.str] service_name: The internal name of your vrack
        :param pulumi.Input[builtins.str] zone: Where you want your block announced on the network
        """
        if block is not None:
            pulumi.set(__self__, "block", block)
        if gateway is not None:
            pulumi.set(__self__, "gateway", gateway)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Your IP block.
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "block", value)

    @property
    @pulumi.getter
    def gateway(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Your gateway
        """
        return pulumi.get(self, "gateway")

    @gateway.setter
    def gateway(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Your IP block
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Where you want your block announced on the network
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone", value)


class IpAddress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Attach an IP block to a VRack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_account = ovh.Me.get_me()
        my_cart = ovh.Order.get_cart(ovh_subsidiary=my_account.ovh_subsidiary)
        vrack = ovh.Order.get_cart_product_plan(cart_id=my_cart.id,
            price_capacity="renew",
            product="vrack",
            plan_code="vrack")
        vrack_vrack = ovh.vrack.Vrack("vrack",
            description=my_cart.description,
            name=my_cart.description,
            ovh_subsidiary=my_cart.ovh_subsidiary,
            plan={
                "duration": vrack.selected_prices[0].duration,
                "plan_code": vrack.plan_code,
                "pricing_mode": vrack.selected_prices[0].pricing_mode,
            })
        ipblock = ovh.Order.get_cart_product_plan(cart_id=my_cart.id,
            price_capacity="renew",
            product="ip",
            plan_code="ip-v4-s30-ripe")
        ipblock_ip_service = ovh.ip.IpService("ipblock",
            ovh_subsidiary=my_cart.ovh_subsidiary,
            description=my_cart.description,
            plan={
                "duration": ipblock.selected_prices[0].duration,
                "plan_code": ipblock.plan_code,
                "pricing_mode": ipblock.selected_prices[0].pricing_mode,
                "configurations": [{
                    "label": "country",
                    "value": "FR",
                }],
            })
        vrack_block = ovh.vrack.IpAddress("vrack_block",
            service_name=vrack_vrack.service_name,
            block=ipblock_ip_service.ip)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] block: Your IP block.
        :param pulumi.Input[builtins.str] service_name: The internal name of your vrack
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Attach an IP block to a VRack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_account = ovh.Me.get_me()
        my_cart = ovh.Order.get_cart(ovh_subsidiary=my_account.ovh_subsidiary)
        vrack = ovh.Order.get_cart_product_plan(cart_id=my_cart.id,
            price_capacity="renew",
            product="vrack",
            plan_code="vrack")
        vrack_vrack = ovh.vrack.Vrack("vrack",
            description=my_cart.description,
            name=my_cart.description,
            ovh_subsidiary=my_cart.ovh_subsidiary,
            plan={
                "duration": vrack.selected_prices[0].duration,
                "plan_code": vrack.plan_code,
                "pricing_mode": vrack.selected_prices[0].pricing_mode,
            })
        ipblock = ovh.Order.get_cart_product_plan(cart_id=my_cart.id,
            price_capacity="renew",
            product="ip",
            plan_code="ip-v4-s30-ripe")
        ipblock_ip_service = ovh.ip.IpService("ipblock",
            ovh_subsidiary=my_cart.ovh_subsidiary,
            description=my_cart.description,
            plan={
                "duration": ipblock.selected_prices[0].duration,
                "plan_code": ipblock.plan_code,
                "pricing_mode": ipblock.selected_prices[0].pricing_mode,
                "configurations": [{
                    "label": "country",
                    "value": "FR",
                }],
            })
        vrack_block = ovh.vrack.IpAddress("vrack_block",
            service_name=vrack_vrack.service_name,
            block=ipblock_ip_service.ip)
        ```

        :param str resource_name: The name of the resource.
        :param IpAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpAddressArgs.__new__(IpAddressArgs)

            if block is None and not opts.urn:
                raise TypeError("Missing required property 'block'")
            __props__.__dict__["block"] = block
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["gateway"] = None
            __props__.__dict__["ip"] = None
            __props__.__dict__["zone"] = None
        super(IpAddress, __self__).__init__(
            'ovh:Vrack/ipAddress:IpAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            block: Optional[pulumi.Input[builtins.str]] = None,
            gateway: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            zone: Optional[pulumi.Input[builtins.str]] = None) -> 'IpAddress':
        """
        Get an existing IpAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] block: Your IP block.
        :param pulumi.Input[builtins.str] gateway: Your gateway
        :param pulumi.Input[builtins.str] ip: Your IP block
        :param pulumi.Input[builtins.str] service_name: The internal name of your vrack
        :param pulumi.Input[builtins.str] zone: Where you want your block announced on the network
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpAddressState.__new__(_IpAddressState)

        __props__.__dict__["block"] = block
        __props__.__dict__["gateway"] = gateway
        __props__.__dict__["ip"] = ip
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["zone"] = zone
        return IpAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def block(self) -> pulumi.Output[builtins.str]:
        """
        Your IP block.
        """
        return pulumi.get(self, "block")

    @property
    @pulumi.getter
    def gateway(self) -> pulumi.Output[builtins.str]:
        """
        Your gateway
        """
        return pulumi.get(self, "gateway")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        Your IP block
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[builtins.str]:
        """
        Where you want your block announced on the network
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstancesResult',
    'AwaitableGetInstancesResult',
    'get_instances',
    'get_instances_output',
]

@pulumi.output_type
class GetInstancesResult:
    """
    A collection of values returned by getInstances.
    """
    def __init__(__self__, id=None, instances=None, region=None, service_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetInstancesInstanceResult']:
        """
        List of instances
        """
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")


class AwaitableGetInstancesResult(GetInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancesResult(
            id=self.id,
            instances=self.instances,
            region=self.region,
            service_name=self.service_name)


def get_instances(region: Optional[builtins.str] = None,
                  service_name: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancesResult:
    """
    **This datasource uses a Beta API**

    Use this data source to get the list of instances in a region of a public cloud project.

    ## Example Usage

    To list your instances:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    instance = ovh.CloudProject.get_instances(service_name="YYYY",
        region="XXXX")
    ```


    :param builtins.str region: Instance region.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult).value

    return AwaitableGetInstancesResult(
        id=pulumi.get(__ret__, 'id'),
        instances=pulumi.get(__ret__, 'instances'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_instances_output(region: Optional[pulumi.Input[builtins.str]] = None,
                         service_name: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstancesResult]:
    """
    **This datasource uses a Beta API**

    Use this data source to get the list of instances in a region of a public cloud project.

    ## Example Usage

    To list your instances:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    instance = ovh.CloudProject.get_instances(service_name="YYYY",
        region="XXXX")
    ```


    :param builtins.str region: Instance region.
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult)
    return __ret__.apply(lambda __response__: GetInstancesResult(
        id=pulumi.get(__response__, 'id'),
        instances=pulumi.get(__response__, 'instances'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FailoverIpAttachArgs', 'FailoverIpAttach']

@pulumi.input_type
class FailoverIpAttachArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[builtins.str],
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 continent_code: Optional[pulumi.Input[builtins.str]] = None,
                 geo_loc: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a FailoverIpAttach resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] block: The IP block
               * `continentCode` - The Ip continent
        :param pulumi.Input[builtins.str] continent_code: Ip continent
        :param pulumi.Input[builtins.str] geo_loc: Ip location
        :param pulumi.Input[builtins.str] ip: The failover ip address to attach
        :param pulumi.Input[builtins.str] routed_to: The GUID of an instance to which the failover IP address is be attached
        """
        pulumi.set(__self__, "service_name", service_name)
        if block is not None:
            pulumi.set(__self__, "block", block)
        if continent_code is not None:
            pulumi.set(__self__, "continent_code", continent_code)
        if geo_loc is not None:
            pulumi.set(__self__, "geo_loc", geo_loc)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if routed_to is not None:
            pulumi.set(__self__, "routed_to", routed_to)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP block
        * `continentCode` - The Ip continent
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "block", value)

    @property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip continent
        """
        return pulumi.get(self, "continent_code")

    @continent_code.setter
    def continent_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "continent_code", value)

    @property
    @pulumi.getter(name="geoLoc")
    def geo_loc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip location
        """
        return pulumi.get(self, "geo_loc")

    @geo_loc.setter
    def geo_loc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "geo_loc", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The failover ip address to attach
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The GUID of an instance to which the failover IP address is be attached
        """
        return pulumi.get(self, "routed_to")

    @routed_to.setter
    def routed_to(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "routed_to", value)


@pulumi.input_type
class _FailoverIpAttachState:
    def __init__(__self__, *,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 continent_code: Optional[pulumi.Input[builtins.str]] = None,
                 geo_loc: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 progress: Optional[pulumi.Input[builtins.int]] = None,
                 routed_to: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 sub_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FailoverIpAttach resources.
        :param pulumi.Input[builtins.str] block: The IP block
               * `continentCode` - The Ip continent
        :param pulumi.Input[builtins.str] continent_code: Ip continent
        :param pulumi.Input[builtins.str] geo_loc: Ip location
        :param pulumi.Input[builtins.str] ip: The failover ip address to attach
        :param pulumi.Input[builtins.int] progress: Current operation progress in percent
               * `routedTo` - Instance where ip is routed to
        :param pulumi.Input[builtins.str] routed_to: The GUID of an instance to which the failover IP address is be attached
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Ip status, can be `ok` or `operationPending`
               * `subType` - IP sub type, can be `cloud` or `ovh`
        :param pulumi.Input[builtins.str] sub_type: IP sub type
        """
        if block is not None:
            pulumi.set(__self__, "block", block)
        if continent_code is not None:
            pulumi.set(__self__, "continent_code", continent_code)
        if geo_loc is not None:
            pulumi.set(__self__, "geo_loc", geo_loc)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if progress is not None:
            pulumi.set(__self__, "progress", progress)
        if routed_to is not None:
            pulumi.set(__self__, "routed_to", routed_to)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sub_type is not None:
            pulumi.set(__self__, "sub_type", sub_type)

    @property
    @pulumi.getter
    def block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP block
        * `continentCode` - The Ip continent
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "block", value)

    @property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip continent
        """
        return pulumi.get(self, "continent_code")

    @continent_code.setter
    def continent_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "continent_code", value)

    @property
    @pulumi.getter(name="geoLoc")
    def geo_loc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip location
        """
        return pulumi.get(self, "geo_loc")

    @geo_loc.setter
    def geo_loc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "geo_loc", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The failover ip address to attach
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def progress(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Current operation progress in percent
        * `routedTo` - Instance where ip is routed to
        """
        return pulumi.get(self, "progress")

    @progress.setter
    def progress(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "progress", value)

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The GUID of an instance to which the failover IP address is be attached
        """
        return pulumi.get(self, "routed_to")

    @routed_to.setter
    def routed_to(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "routed_to", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip status, can be `ok` or `operationPending`
        * `subType` - IP sub type, can be `cloud` or `ovh`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subType")
    def sub_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP sub type
        """
        return pulumi.get(self, "sub_type")

    @sub_type.setter
    def sub_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sub_type", value)


class FailoverIpAttach(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 continent_code: Optional[pulumi.Input[builtins.str]] = None,
                 geo_loc: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Attaches a failover IP address to a compute instance

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_failover_ip = ovh.cloud_project.FailoverIpAttach("my_failover_ip",
            service_name="XXXXXX",
            ip="XXXXXX",
            routed_to="XXXXXX")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] block: The IP block
               * `continentCode` - The Ip continent
        :param pulumi.Input[builtins.str] continent_code: Ip continent
        :param pulumi.Input[builtins.str] geo_loc: Ip location
        :param pulumi.Input[builtins.str] ip: The failover ip address to attach
        :param pulumi.Input[builtins.str] routed_to: The GUID of an instance to which the failover IP address is be attached
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FailoverIpAttachArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Attaches a failover IP address to a compute instance

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_failover_ip = ovh.cloud_project.FailoverIpAttach("my_failover_ip",
            service_name="XXXXXX",
            ip="XXXXXX",
            routed_to="XXXXXX")
        ```

        :param str resource_name: The name of the resource.
        :param FailoverIpAttachArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FailoverIpAttachArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[builtins.str]] = None,
                 continent_code: Optional[pulumi.Input[builtins.str]] = None,
                 geo_loc: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 routed_to: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FailoverIpAttachArgs.__new__(FailoverIpAttachArgs)

            __props__.__dict__["block"] = block
            __props__.__dict__["continent_code"] = continent_code
            __props__.__dict__["geo_loc"] = geo_loc
            __props__.__dict__["ip"] = ip
            __props__.__dict__["routed_to"] = routed_to
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["progress"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["sub_type"] = None
        super(FailoverIpAttach, __self__).__init__(
            'ovh:CloudProject/failoverIpAttach:FailoverIpAttach',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            block: Optional[pulumi.Input[builtins.str]] = None,
            continent_code: Optional[pulumi.Input[builtins.str]] = None,
            geo_loc: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            progress: Optional[pulumi.Input[builtins.int]] = None,
            routed_to: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            sub_type: Optional[pulumi.Input[builtins.str]] = None) -> 'FailoverIpAttach':
        """
        Get an existing FailoverIpAttach resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] block: The IP block
               * `continentCode` - The Ip continent
        :param pulumi.Input[builtins.str] continent_code: Ip continent
        :param pulumi.Input[builtins.str] geo_loc: Ip location
        :param pulumi.Input[builtins.str] ip: The failover ip address to attach
        :param pulumi.Input[builtins.int] progress: Current operation progress in percent
               * `routedTo` - Instance where ip is routed to
        :param pulumi.Input[builtins.str] routed_to: The GUID of an instance to which the failover IP address is be attached
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Ip status, can be `ok` or `operationPending`
               * `subType` - IP sub type, can be `cloud` or `ovh`
        :param pulumi.Input[builtins.str] sub_type: IP sub type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FailoverIpAttachState.__new__(_FailoverIpAttachState)

        __props__.__dict__["block"] = block
        __props__.__dict__["continent_code"] = continent_code
        __props__.__dict__["geo_loc"] = geo_loc
        __props__.__dict__["ip"] = ip
        __props__.__dict__["progress"] = progress
        __props__.__dict__["routed_to"] = routed_to
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["sub_type"] = sub_type
        return FailoverIpAttach(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def block(self) -> pulumi.Output[builtins.str]:
        """
        The IP block
        * `continentCode` - The Ip continent
        """
        return pulumi.get(self, "block")

    @property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> pulumi.Output[builtins.str]:
        """
        Ip continent
        """
        return pulumi.get(self, "continent_code")

    @property
    @pulumi.getter(name="geoLoc")
    def geo_loc(self) -> pulumi.Output[builtins.str]:
        """
        Ip location
        """
        return pulumi.get(self, "geo_loc")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        The failover ip address to attach
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def progress(self) -> pulumi.Output[builtins.int]:
        """
        Current operation progress in percent
        * `routedTo` - Instance where ip is routed to
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> pulumi.Output[builtins.str]:
        """
        The GUID of an instance to which the failover IP address is be attached
        """
        return pulumi.get(self, "routed_to")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Ip status, can be `ok` or `operationPending`
        * `subType` - IP sub type, can be `cloud` or `ovh`
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subType")
    def sub_type(self) -> pulumi.Output[builtins.str]:
        """
        IP sub type
        """
        return pulumi.get(self, "sub_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RegionStoragePresignArgs', 'RegionStoragePresign']

@pulumi.input_type
class RegionStoragePresignArgs:
    def __init__(__self__, *,
                 expire: pulumi.Input[builtins.int],
                 method: pulumi.Input[builtins.str],
                 object: pulumi.Input[builtins.str],
                 region_name: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 version_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RegionStoragePresign resource.
        :param pulumi.Input[builtins.int] expire: Define, in seconds, for how long your URL will be valid.
        :param pulumi.Input[builtins.str] method: The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        :param pulumi.Input[builtins.str] object: The name of the object in your S3 bucket.
        :param pulumi.Input[builtins.str] region_name: The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] name: The name of your S3 storage container/bucket.
        :param pulumi.Input[builtins.str] version_id: Version ID of the object to download or delete
        """
        pulumi.set(__self__, "expire", expire)
        pulumi.set(__self__, "method", method)
        pulumi.set(__self__, "object", object)
        pulumi.set(__self__, "region_name", region_name)
        pulumi.set(__self__, "service_name", service_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version_id is not None:
            pulumi.set(__self__, "version_id", version_id)

    @property
    @pulumi.getter
    def expire(self) -> pulumi.Input[builtins.int]:
        """
        Define, in seconds, for how long your URL will be valid.
        """
        return pulumi.get(self, "expire")

    @expire.setter
    def expire(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "expire", value)

    @property
    @pulumi.getter
    def method(self) -> pulumi.Input[builtins.str]:
        """
        The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        """
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "method", value)

    @property
    @pulumi.getter
    def object(self) -> pulumi.Input[builtins.str]:
        """
        The name of the object in your S3 bucket.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Input[builtins.str]:
        """
        The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of your S3 storage container/bucket.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Version ID of the object to download or delete
        """
        return pulumi.get(self, "version_id")

    @version_id.setter
    def version_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_id", value)


@pulumi.input_type
class _RegionStoragePresignState:
    def __init__(__self__, *,
                 expire: Optional[pulumi.Input[builtins.int]] = None,
                 method: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 object: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 signed_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 version_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RegionStoragePresign resources.
        :param pulumi.Input[builtins.int] expire: Define, in seconds, for how long your URL will be valid.
        :param pulumi.Input[builtins.str] method: The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        :param pulumi.Input[builtins.str] name: The name of your S3 storage container/bucket.
        :param pulumi.Input[builtins.str] object: The name of the object in your S3 bucket.
        :param pulumi.Input[builtins.str] region_name: The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] signed_headers: Map of signed headers.
        :param pulumi.Input[builtins.str] url: Computed URL result.
        :param pulumi.Input[builtins.str] version_id: Version ID of the object to download or delete
        """
        if expire is not None:
            pulumi.set(__self__, "expire", expire)
        if method is not None:
            pulumi.set(__self__, "method", method)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if object is not None:
            pulumi.set(__self__, "object", object)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if signed_headers is not None:
            pulumi.set(__self__, "signed_headers", signed_headers)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if version_id is not None:
            pulumi.set(__self__, "version_id", version_id)

    @property
    @pulumi.getter
    def expire(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Define, in seconds, for how long your URL will be valid.
        """
        return pulumi.get(self, "expire")

    @expire.setter
    def expire(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "expire", value)

    @property
    @pulumi.getter
    def method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        """
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "method", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of your S3 storage container/bucket.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def object(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the object in your S3 bucket.
        """
        return pulumi.get(self, "object")

    @object.setter
    def object(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "object", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="signedHeaders")
    def signed_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Map of signed headers.
        """
        return pulumi.get(self, "signed_headers")

    @signed_headers.setter
    def signed_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "signed_headers", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Computed URL result.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Version ID of the object to download or delete
        """
        return pulumi.get(self, "version_id")

    @version_id.setter
    def version_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_id", value)


class RegionStoragePresign(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expire: Optional[pulumi.Input[builtins.int]] = None,
                 method: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 object: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 version_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Generates a temporary presigned S3 URLs to download or upload an object.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        presigned_url = ovh.cloud_project.RegionStoragePresign("presigned_url",
            service_name="xxxxxxxxxxxxxxxxx",
            region_name="GRA",
            name="s3-bucket-name",
            expire=3600,
            method="GET",
            object="an-object-in-the-bucket")
        pulumi.export("presignedUrl", presigned_url.url)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] expire: Define, in seconds, for how long your URL will be valid.
        :param pulumi.Input[builtins.str] method: The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        :param pulumi.Input[builtins.str] name: The name of your S3 storage container/bucket.
        :param pulumi.Input[builtins.str] object: The name of the object in your S3 bucket.
        :param pulumi.Input[builtins.str] region_name: The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] version_id: Version ID of the object to download or delete
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegionStoragePresignArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Generates a temporary presigned S3 URLs to download or upload an object.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        presigned_url = ovh.cloud_project.RegionStoragePresign("presigned_url",
            service_name="xxxxxxxxxxxxxxxxx",
            region_name="GRA",
            name="s3-bucket-name",
            expire=3600,
            method="GET",
            object="an-object-in-the-bucket")
        pulumi.export("presignedUrl", presigned_url.url)
        ```

        :param str resource_name: The name of the resource.
        :param RegionStoragePresignArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegionStoragePresignArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expire: Optional[pulumi.Input[builtins.int]] = None,
                 method: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 object: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 version_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegionStoragePresignArgs.__new__(RegionStoragePresignArgs)

            if expire is None and not opts.urn:
                raise TypeError("Missing required property 'expire'")
            __props__.__dict__["expire"] = expire
            if method is None and not opts.urn:
                raise TypeError("Missing required property 'method'")
            __props__.__dict__["method"] = method
            __props__.__dict__["name"] = name
            if object is None and not opts.urn:
                raise TypeError("Missing required property 'object'")
            __props__.__dict__["object"] = object
            if region_name is None and not opts.urn:
                raise TypeError("Missing required property 'region_name'")
            __props__.__dict__["region_name"] = region_name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["version_id"] = version_id
            __props__.__dict__["signed_headers"] = None
            __props__.__dict__["url"] = None
        super(RegionStoragePresign, __self__).__init__(
            'ovh:CloudProject/regionStoragePresign:RegionStoragePresign',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            expire: Optional[pulumi.Input[builtins.int]] = None,
            method: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            object: Optional[pulumi.Input[builtins.str]] = None,
            region_name: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            signed_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None,
            version_id: Optional[pulumi.Input[builtins.str]] = None) -> 'RegionStoragePresign':
        """
        Get an existing RegionStoragePresign resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] expire: Define, in seconds, for how long your URL will be valid.
        :param pulumi.Input[builtins.str] method: The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        :param pulumi.Input[builtins.str] name: The name of your S3 storage container/bucket.
        :param pulumi.Input[builtins.str] object: The name of the object in your S3 bucket.
        :param pulumi.Input[builtins.str] region_name: The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] signed_headers: Map of signed headers.
        :param pulumi.Input[builtins.str] url: Computed URL result.
        :param pulumi.Input[builtins.str] version_id: Version ID of the object to download or delete
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegionStoragePresignState.__new__(_RegionStoragePresignState)

        __props__.__dict__["expire"] = expire
        __props__.__dict__["method"] = method
        __props__.__dict__["name"] = name
        __props__.__dict__["object"] = object
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["signed_headers"] = signed_headers
        __props__.__dict__["url"] = url
        __props__.__dict__["version_id"] = version_id
        return RegionStoragePresign(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def expire(self) -> pulumi.Output[builtins.int]:
        """
        Define, in seconds, for how long your URL will be valid.
        """
        return pulumi.get(self, "expire")

    @property
    @pulumi.getter
    def method(self) -> pulumi.Output[builtins.str]:
        """
        The method you want to use to interact with your object. Can be either 'GET' or 'PUT'.
        """
        return pulumi.get(self, "method")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of your S3 storage container/bucket.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def object(self) -> pulumi.Output[builtins.str]:
        """
        The name of the object in your S3 bucket.
        """
        return pulumi.get(self, "object")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[builtins.str]:
        """
        The region in which your storage is located. Must be in **uppercase**. Ex.: "GRA".
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="signedHeaders")
    def signed_headers(self) -> pulumi.Output[Mapping[str, builtins.str]]:
        """
        Map of signed headers.
        """
        return pulumi.get(self, "signed_headers")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        Computed URL result.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Version ID of the object to download or delete
        """
        return pulumi.get(self, "version_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IpServiceArgs', 'IpService']

@pulumi.input_type
class IpServiceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['IpServicePlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]] = None):
        """
        The set of arguments for constructing a IpService resource.
        :param pulumi.Input[builtins.str] description: Custom description on your ip.
        :param pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['IpServicePlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]] plan_options: Product Plan to order
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom description on your ip.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['IpServicePlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['IpServicePlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)


@pulumi.input_type
class _IpServiceState:
    def __init__(__self__, *,
                 can_be_terminated: Optional[pulumi.Input[builtins.bool]] = None,
                 country: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]] = None,
                 organisation_id: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input['IpServicePlanArgs']] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]] = None,
                 routed_tos: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceRoutedToArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpService resources.
        :param pulumi.Input[builtins.bool] can_be_terminated: can be terminated
        :param pulumi.Input[builtins.str] country: country
        :param pulumi.Input[builtins.str] description: Custom description on your ip.
        :param pulumi.Input[builtins.str] ip: ip block
        :param pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]] orders: Details about an Order
        :param pulumi.Input[builtins.str] organisation_id: IP block organisation Id
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input['IpServicePlanArgs'] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]] plan_options: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input['IpServiceRoutedToArgs']]] routed_tos: Routage information
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] type: Possible values for ip type
        """
        if can_be_terminated is not None:
            pulumi.set(__self__, "can_be_terminated", can_be_terminated)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if orders is not None:
            pulumi.set(__self__, "orders", orders)
        if organisation_id is not None:
            pulumi.set(__self__, "organisation_id", organisation_id)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if payment_mean is not None:
            warnings.warn("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""", DeprecationWarning)
            pulumi.log.warn("""payment_mean is deprecated: This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
        if payment_mean is not None:
            pulumi.set(__self__, "payment_mean", payment_mean)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if routed_tos is not None:
            pulumi.set(__self__, "routed_tos", routed_tos)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="canBeTerminated")
    def can_be_terminated(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        can be terminated
        """
        return pulumi.get(self, "can_be_terminated")

    @can_be_terminated.setter
    def can_be_terminated(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "can_be_terminated", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        country
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom description on your ip.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ip block
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def orders(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @orders.setter
    def orders(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderArgs']]]]):
        pulumi.set(self, "orders", value)

    @property
    @pulumi.getter(name="organisationId")
    def organisation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP block organisation Id
        """
        return pulumi.get(self, "organisation_id")

    @organisation_id.setter
    def organisation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "organisation_id", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @payment_mean.setter
    def payment_mean(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payment_mean", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input['IpServicePlanArgs']]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input['IpServicePlanArgs']]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter(name="routedTos")
    def routed_tos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceRoutedToArgs']]]]:
        """
        Routage information
        """
        return pulumi.get(self, "routed_tos")

    @routed_tos.setter
    def routed_tos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceRoutedToArgs']]]]):
        pulumi.set(self, "routed_tos", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Possible values for ip type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


class IpService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServiceOrderArgs', 'IpServiceOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['IpServicePlanArgs', 'IpServicePlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServicePlanOptionArgs', 'IpServicePlanOptionArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary="fr")
        ipblock = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="ip",
            plan_code="ip-v4-s30-ripe")
        ipblock_ip_service = ovh.ip.IpService("ipblock",
            ovh_subsidiary=mycart.ovh_subsidiary,
            description="my ip block",
            plan={
                "duration": ipblock.selected_prices[0].duration,
                "plan_code": ipblock.plan_code,
                "pricing_mode": ipblock.selected_prices[0].pricing_mode,
                "configurations": [
                    {
                        "label": "country",
                        "value": "FR",
                    },
                    {
                        "label": "region",
                        "value": "europe",
                    },
                    {
                        "label": "destination",
                        "value": "parking",
                    },
                ],
            })
        ```

        ## Import

        The resource can be imported using its `service_name`, E.g.,

        terraform

        import {

          to = ovh_ip_service.ipblock

          id = "ip-xx.xx.xx.xx"

        }

        bash

        $ pulumi preview -generate-config-out=ipblock.tf

        $ pulumi up

        The file `ipblock.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Custom description on your ip.
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpServiceOrderArgs', 'IpServiceOrderArgsDict']]]] orders: Details about an Order
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['IpServicePlanArgs', 'IpServicePlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpServicePlanOptionArgs', 'IpServicePlanOptionArgsDict']]]] plan_options: Product Plan to order
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IpServiceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        myaccount = ovh.Me.get_me()
        mycart = ovh.Order.get_cart(ovh_subsidiary="fr")
        ipblock = ovh.Order.get_cart_product_plan(cart_id=mycart.id,
            price_capacity="renew",
            product="ip",
            plan_code="ip-v4-s30-ripe")
        ipblock_ip_service = ovh.ip.IpService("ipblock",
            ovh_subsidiary=mycart.ovh_subsidiary,
            description="my ip block",
            plan={
                "duration": ipblock.selected_prices[0].duration,
                "plan_code": ipblock.plan_code,
                "pricing_mode": ipblock.selected_prices[0].pricing_mode,
                "configurations": [
                    {
                        "label": "country",
                        "value": "FR",
                    },
                    {
                        "label": "region",
                        "value": "europe",
                    },
                    {
                        "label": "destination",
                        "value": "parking",
                    },
                ],
            })
        ```

        ## Import

        The resource can be imported using its `service_name`, E.g.,

        terraform

        import {

          to = ovh_ip_service.ipblock

          id = "ip-xx.xx.xx.xx"

        }

        bash

        $ pulumi preview -generate-config-out=ipblock.tf

        $ pulumi up

        The file `ipblock.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param IpServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServiceOrderArgs', 'IpServiceOrderArgsDict']]]]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 payment_mean: Optional[pulumi.Input[builtins.str]] = None,
                 plan: Optional[pulumi.Input[Union['IpServicePlanArgs', 'IpServicePlanArgsDict']]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServicePlanOptionArgs', 'IpServicePlanOptionArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpServiceArgs.__new__(IpServiceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["orders"] = orders
            __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
            __props__.__dict__["payment_mean"] = payment_mean
            __props__.__dict__["plan"] = plan
            __props__.__dict__["plan_options"] = plan_options
            __props__.__dict__["can_be_terminated"] = None
            __props__.__dict__["country"] = None
            __props__.__dict__["ip"] = None
            __props__.__dict__["organisation_id"] = None
            __props__.__dict__["routed_tos"] = None
            __props__.__dict__["service_name"] = None
            __props__.__dict__["type"] = None
        super(IpService, __self__).__init__(
            'ovh:Ip/ipService:IpService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_be_terminated: Optional[pulumi.Input[builtins.bool]] = None,
            country: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            orders: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServiceOrderArgs', 'IpServiceOrderArgsDict']]]]] = None,
            organisation_id: Optional[pulumi.Input[builtins.str]] = None,
            ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
            payment_mean: Optional[pulumi.Input[builtins.str]] = None,
            plan: Optional[pulumi.Input[Union['IpServicePlanArgs', 'IpServicePlanArgsDict']]] = None,
            plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServicePlanOptionArgs', 'IpServicePlanOptionArgsDict']]]]] = None,
            routed_tos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpServiceRoutedToArgs', 'IpServiceRoutedToArgsDict']]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'IpService':
        """
        Get an existing IpService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] can_be_terminated: can be terminated
        :param pulumi.Input[builtins.str] country: country
        :param pulumi.Input[builtins.str] description: Custom description on your ip.
        :param pulumi.Input[builtins.str] ip: ip block
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpServiceOrderArgs', 'IpServiceOrderArgsDict']]]] orders: Details about an Order
        :param pulumi.Input[builtins.str] organisation_id: IP block organisation Id
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        :param pulumi.Input[builtins.str] payment_mean: Ovh payment mode
        :param pulumi.Input[Union['IpServicePlanArgs', 'IpServicePlanArgsDict']] plan: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpServicePlanOptionArgs', 'IpServicePlanOptionArgsDict']]]] plan_options: Product Plan to order
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpServiceRoutedToArgs', 'IpServiceRoutedToArgsDict']]]] routed_tos: Routage information
        :param pulumi.Input[builtins.str] service_name: service name
        :param pulumi.Input[builtins.str] type: Possible values for ip type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpServiceState.__new__(_IpServiceState)

        __props__.__dict__["can_be_terminated"] = can_be_terminated
        __props__.__dict__["country"] = country
        __props__.__dict__["description"] = description
        __props__.__dict__["ip"] = ip
        __props__.__dict__["orders"] = orders
        __props__.__dict__["organisation_id"] = organisation_id
        __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
        __props__.__dict__["payment_mean"] = payment_mean
        __props__.__dict__["plan"] = plan
        __props__.__dict__["plan_options"] = plan_options
        __props__.__dict__["routed_tos"] = routed_tos
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["type"] = type
        return IpService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canBeTerminated")
    def can_be_terminated(self) -> pulumi.Output[builtins.bool]:
        """
        can be terminated
        """
        return pulumi.get(self, "can_be_terminated")

    @property
    @pulumi.getter
    def country(self) -> pulumi.Output[builtins.str]:
        """
        country
        """
        return pulumi.get(self, "country")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Custom description on your ip.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        ip block
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def orders(self) -> pulumi.Output[Sequence['outputs.IpServiceOrder']]:
        """
        Details about an Order
        """
        return pulumi.get(self, "orders")

    @property
    @pulumi.getter(name="organisationId")
    def organisation_id(self) -> pulumi.Output[builtins.str]:
        """
        IP block organisation Id
        """
        return pulumi.get(self, "organisation_id")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Output[builtins.str]:
        """
        OVHcloud Subsidiary. Country of OVHcloud legal entity you'll be billed by. List of supported subsidiaries available on API at [/1.0/me.json under `models.nichandle.OvhSubsidiaryEnum`](https://eu.api.ovh.com/1.0/me.json)
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter(name="paymentMean")
    @_utilities.deprecated("""This field is not anymore used since the API has been deprecated in favor of /payment/mean. Now, the default payment mean is used.""")
    def payment_mean(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Ovh payment mode
        """
        return pulumi.get(self, "payment_mean")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output['outputs.IpServicePlan']:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> pulumi.Output[Optional[Sequence['outputs.IpServicePlanOption']]]:
        """
        Product Plan to order
        """
        return pulumi.get(self, "plan_options")

    @property
    @pulumi.getter(name="routedTos")
    def routed_tos(self) -> pulumi.Output[Sequence['outputs.IpServiceRoutedTo']]:
        """
        Routage information
        """
        return pulumi.get(self, "routed_tos")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Possible values for ip type
        """
        return pulumi.get(self, "type")

